==> odoo_17.0.20260115.zip: odoo-17.0.post20260115/odoo/addons/mass_mailing/static/tests/tours/snippets_mailing_menu_tabs.js <==
/** @odoo-module **/

import { registry } from "@web/core/registry";
import { stepUtils } from "@web_tour/tour_service/tour_utils";

registry.category("web_tour.tours").add('snippets_mailing_menu_tabs', {
    test: true,
    url: '/web',
    steps: () => [
    stepUtils.showAppsMenuItem(), {
        content: "Select the 'Email Marketing' app.",
        trigger: '.o_app[data-menu-xmlid="mass_mailing.mass_mailing_menu_root"]',
    },
    {
        content: "Click on the create button to create a new mailing.",
        trigger: 'button.o_list_button_add',
    },
    {
        content: "Click on the 'Start From Scratch' template.",
        trigger: 'iframe #empty',
    },
    {
        content: "Click on the 'Design' tab.",
        trigger: 'iframe .o_we_customize_design_btn',
    },
    {
        content: "Click on the empty 'DRAG BUILDING BLOCKS HERE' area.",
        trigger: 'iframe .oe_structure.o_mail_no_options',
    },
    {
        content: "Click on the 'Design' tab.",
        trigger: 'iframe .o_we_customize_design_btn',
    },
    {
        content: "Verify that the customize panel is not empty.",
        trigger: 'iframe .o_we_customize_panel .snippet-option-DesignTab',
        run: () => null, // it's a check
    },
    {
        content: "Click on the style tab.",
        trigger: 'iframe .o_we_customize_snippet_btn',
    },
    {
        content: "Click on the 'Design' tab.",
        trigger: 'iframe .o_we_customize_design_btn',
    },
    {
        content: "Verify that the customize panel is not empty.",
        trigger: 'iframe .o_we_customize_panel .snippet-option-DesignTab',
        run: () => null, // it's a check
    },
    ...stepUtils.discardForm(),
]});

==> odoo_18.0.20250926.zip: odoo-18.0.post20250926/odoo/addons/mass_mailing/static/tests/tours/snippets_mailing_menu_tabs.js <==
/** @odoo-module **/

import { registry } from "@web/core/registry";
import { stepUtils } from "@web_tour/tour_service/tour_utils";

registry.category("web_tour.tours").add('snippets_mailing_menu_tabs', {
    url: '/odoo',
    steps: () => [
    stepUtils.showAppsMenuItem(), {
        content: "Select the 'Email Marketing' app.",
        trigger: '.o_app[data-menu-xmlid="mass_mailing.mass_mailing_menu_root"]',
        run: "click",
    },
    {
        content: "Click on the create button to create a new mailing.",
        trigger: 'button.o_list_button_add',
        run: "click",
    },
    {
        content: "Click on the 'Start From Scratch' template.",
        trigger: ':iframe #empty',
        run: "click",
    },
    {
        content: "Click on the 'Design' tab.",
        trigger: '.o_we_customize_design_btn',
        run: "click",
    },
    {
        content: "Click on the empty 'DRAG BUILDING BLOCKS HERE' area.",
        trigger: ':iframe .oe_structure.o_mail_no_options',
        run: "click",
    },
    {
        content: "Click on the 'Design' tab.",
        trigger: '.o_we_customize_design_btn',
        run: "click",
    },
    {
        content: "Verify that the customize panel is not empty.",
        trigger: '.o_we_customize_panel .snippet-option-DesignTab',
    },
    {
        content: "Click on the style tab.",
        trigger: '.o_we_customize_snippet_btn',
        run: "click",
    },
    {
        content: "Click on the 'Design' tab.",
        trigger: '.o_we_customize_design_btn',
        run: "click",
    },
    {
        content: "Verify that the customize panel is not empty.",
        trigger: '.o_we_customize_panel .snippet-option-DesignTab',
    },
    ...stepUtils.discardForm(),
]});
